@@ -2,19 +2,7 @@ from matplotlib import pyplot
 from shapely.geometry import Polygon
 from descartes.patch import PolygonPatch
 
-from figures import SIZE
-
-COLOR = {
-    True:  '#6699cc',
-    False: '#ff3333'
-    }
-
-def v_color(ob):
-    return COLOR[ob.is_valid]
-
-def plot_coords(ax, ob):
-    x, y = ob.xy
-    ax.plot(x, y, 'o', color='#999999', zorder=1)
+from figures import BLUE, SIZE, set_limits, plot_coords, color_isvalid
     
 fig = pyplot.figure(1, figsize=SIZE, dpi=90)
 
@@ -28,18 +16,12 @@ polygon = Polygon(ext, [int])
 plot_coords(ax, polygon.interiors[0])
 plot_coords(ax, polygon.exterior)
 
-patch = PolygonPatch(polygon, facecolor=v_color(polygon), edgecolor=v_color(polygon), alpha=0.5, zorder=2)
+patch = PolygonPatch(polygon, facecolor=color_isvalid(polygon), edgecolor=color_isvalid(polygon, valid=BLUE), alpha=0.5, zorder=2)
 ax.add_patch(patch)
 
 ax.set_title('a) valid')
 
-xrange = [-1, 3]
-yrange = [-1, 3]
-ax.set_xlim(*xrange)
-ax.set_xticks(range(*xrange) + [xrange[-1]])
-ax.set_ylim(*yrange)
-ax.set_yticks(range(*yrange) + [yrange[-1]])
-ax.set_aspect(1)
+set_limits(ax, -1, 3, -1, 3)
 
 #2: invalid self-touching ring
 ax = fig.add_subplot(122)
@@ -50,18 +32,12 @@ polygon = Polygon(ext, [int])
 plot_coords(ax, polygon.interiors[0])
 plot_coords(ax, polygon.exterior)
 
-patch = PolygonPatch(polygon, facecolor=v_color(polygon), edgecolor=v_color(polygon), alpha=0.5, zorder=2)
+patch = PolygonPatch(polygon, facecolor=color_isvalid(polygon), edgecolor=color_isvalid(polygon, valid=BLUE), alpha=0.5, zorder=2)
 ax.add_patch(patch)
 
 ax.set_title('b) invalid')
 
-xrange = [-1, 3]
-yrange = [-1, 3]
-ax.set_xlim(*xrange)
-ax.set_xticks(range(*xrange) + [xrange[-1]])
-ax.set_ylim(*yrange)
-ax.set_yticks(range(*yrange) + [yrange[-1]])
-ax.set_aspect(1)
+set_limits(ax, -1, 3, -1, 3)
 
 pyplot.show()
 
