@@ -6,7 +6,7 @@ import sys
 if sys.version_info[0] < 3:
     range = xrange
 
-from ctypes import c_double, cast, POINTER
+from ctypes import c_double
 
 from shapely.geos import lgeos, TopologicalError
 from shapely.geometry.base import (
@@ -69,7 +69,7 @@ class LineString(BaseGeometry):
             return '<g />'
         if stroke_color is None:
             stroke_color = "#66cc99" if self.is_valid else "#ff3333"
-        pnt_format = " ".join(["{0},{1}".format(*c) for c in self.coords])
+        pnt_format = " ".join(["{},{}".format(*c) for c in self.coords])
         return (
             '<polyline fill="none" stroke="{2}" stroke-width="{1}" '
             'points="{0}" opacity="0.8" />'
@@ -213,6 +213,10 @@ def geos_linestring_from_py(ob, update_geom=None, update_ndim=0):
     elif m == 1:
         raise ValueError("LineStrings must have at least 2 coordinate tuples")
 
+    if m < 2:
+        raise ValueError(
+            "LineStrings must have at least 2 coordinate tuples")
+
     def _coords(o):
         if isinstance(o, Point):
             return o.coords[0]
@@ -252,7 +256,10 @@ def geos_linestring_from_py(ob, update_geom=None, update_ndim=0):
     if update_geom is not None:
         return None
     else:
-        return lgeos.GEOSGeom_createLineString(cs), n
+        ptr = lgeos.GEOSGeom_createLineString(cs)
+        if not ptr:
+            raise ValueError("GEOSGeom_createLineString returned a NULL pointer")
+        return ptr, n
 
 
 def update_linestring_from_py(geom, ob):
