@@ -11,12 +11,16 @@ else:
 from ctypes import byref, c_void_p, c_double
 
 from shapely.geos import lgeos
-from shapely.geometry.base import geom_factory, BaseGeometry
+from shapely.geometry.base import geom_factory, BaseGeometry, BaseMultipartGeometry
 from shapely.geometry import asShape, asLineString, asMultiLineString, Point, MultiPoint,\
                              LineString, MultiLineString, Polygon, GeometryCollection
+from shapely.geometry.polygon import orient as orient_
+from shapely.algorithms.polylabel import polylabel
+
 
 __all__ = ['cascaded_union', 'linemerge', 'operator', 'polygonize',
-           'polygonize_full', 'transform', 'unary_union', 'triangulate', 'split']
+           'polygonize_full', 'transform', 'unary_union', 'triangulate',
+           'split', 'section']
 
 
 class CollectionOperator(object):
@@ -117,7 +121,7 @@ class CollectionOperator(object):
     def cascaded_union(self, geoms):
         """Returns the union of a sequence of geometries
 
-        This is the most efficient method of dissolving many polygons.
+        This method was superseded by :meth:`unary_union`.
         """
         try:
             L = len(geoms)
@@ -135,7 +139,6 @@ class CollectionOperator(object):
 
         This method replaces :meth:`cascaded_union` as the
         prefered method for dissolving many polygons.
-
         """
         try:
             L = len(geoms)
@@ -385,22 +388,28 @@ class SplitOp(object):
         distance_on_line = line.project(splitter)
         coords = list(line.coords)
         # split the line at the point and create two new lines
-        # TODO: can optimize this by accumulating the computed point-to-point distances
-        for i, p in enumerate(coords):
-            pd = line.project(Point(p))
-            if pd == distance_on_line:
+        current_position = 0.0
+        for i in range(len(coords)-1):
+            point1 = coords[i]
+            point2 = coords[i+1]
+            dx = point1[0] - point2[0]
+            dy = point1[1] - point2[1]
+            segment_length = (dx ** 2 + dy ** 2) ** 0.5
+            current_position += segment_length
+            if distance_on_line == current_position:
+                # splitter is exactly on a vertex
                 return [
-                    LineString(coords[:i+1]),
-                    LineString(coords[i:])
+                    LineString(coords[:i+2]),
+                    LineString(coords[i+1:])
                 ]
-            elif distance_on_line < pd:
-                # we must interpolate here because the line might use 3D points
-                cp = line.interpolate(distance_on_line)
-                ls1_coords = coords[:i]
-                ls1_coords.append(cp.coords[0])
-                ls2_coords = [cp.coords[0]]
-                ls2_coords.extend(coords[i:])
-                return [LineString(ls1_coords), LineString(ls2_coords)]
+            elif distance_on_line < current_position:
+                # splitter is between two vertices
+                return [
+                    LineString(coords[:i+1] + [splitter.coords[0]]),
+                    LineString([splitter.coords[0]] + coords[i+1:])
+                ]
+        return [line]
+
 
     @staticmethod
     def _split_line_with_multipoint(line, splitter):
@@ -475,3 +484,104 @@ class SplitOp(object):
         return GeometryCollection(split_func(geom, splitter))
 
 split = SplitOp.split
+
+
+def substring(geom, start_dist, end_dist, normalized=False):
+    """Return a line segment between specified distances along a linear geometry.
+
+    Negative distance values are taken as measured in the reverse
+    direction from the end of the geometry. Out-of-range index
+    values are handled by clamping them to the valid range of values.
+    If the start distances equals the end distance, a point is being returned.
+    If the normalized arg is True, the distance will be interpreted as a
+    fraction of the geometry's length.
+    """
+
+    assert(isinstance(geom, LineString))
+    
+    # Filter out cases in which to return a point
+    if start_dist == end_dist:
+        return geom.interpolate(start_dist, normalized)
+    elif not normalized and start_dist >= geom.length and end_dist >= geom.length:
+        return geom.interpolate(geom.length, normalized)
+    elif not normalized and -start_dist >= geom.length and -end_dist >= geom.length:
+        return geom.interpolate(0, normalized)                    
+    elif normalized and start_dist >= 1 and end_dist >= 1:
+        return geom.interpolate(1, normalized)  
+    elif normalized and -start_dist >= 1 and -end_dist >= 1:
+        return geom.interpolate(0, normalized)
+
+    start_point = geom.interpolate(start_dist, normalized)
+    end_point = geom.interpolate(end_dist, normalized)
+    
+    min_dist = min(start_dist, end_dist)
+    max_dist = max(start_dist, end_dist)
+    if normalized:
+        min_dist *= geom.length
+        max_dist *= geom.length
+    
+    if start_dist < end_dist:
+        vertex_list = [(start_point.x, start_point.y)]
+    else:
+        vertex_list = [(end_point.x, end_point.y)]
+    coords = list(geom.coords)
+    for p in coords:
+        pd = geom.project(Point(p))
+        if min_dist < pd < max_dist:
+            vertex_list.append(p)
+        elif pd >= max_dist:
+            break
+    if start_dist < end_dist:
+        vertex_list.append((end_point.x, end_point.y))
+    else:
+        vertex_list.append((start_point.x, start_point.y))
+        # reverse direction result
+        vertex_list = reversed(vertex_list)
+
+    return LineString(vertex_list)
+
+
+def clip_by_rect(geom, xmin, ymin, xmax, ymax):
+    """Returns the portion of a geometry within a rectangle
+
+    The geometry is clipped in a fast but possibly dirty way. The output is
+    not guaranteed to be valid. No exceptions will be raised for topological
+    errors.
+
+    Parameters
+    ----------
+    geom : geometry
+        The geometry to be clipped
+    xmin : float
+        Minimum x value of the rectangle
+    ymin : float
+        Minimum y value of the rectangle
+    xmax : float
+        Maximum x value of the rectangle
+    ymax : float
+        Maximum y value of the rectangle
+
+    Notes
+    -----
+    Requires GEOS >= 3.5.0
+    New in 1.7.
+    """
+    if geom.is_empty:
+        return geom
+    result = geom_factory(lgeos.methods['clip_by_rect'](geom._geom, xmin, ymin, xmax, ymax))
+    return result
+
+
+def orient(geom, sign=1.0):
+    if isinstance(geom, BaseMultipartGeometry):
+        return geom.__class__(
+            list(
+                map(
+                    lambda geom: orient(geom, sign),
+                    geom.geoms,
+                )
+            )
+        )
+    if isinstance(geom, (Polygon,)):
+        return orient_(geom, sign)
+    return geom
