@@ -1,4 +1,5 @@
 from . import unittest, numpy
+import pytest
 from shapely.geos import lgeos
 from shapely.geometry import LineString, asLineString, Point, LinearRing
 
@@ -60,17 +61,17 @@ class LineStringTestCase(unittest.TestCase):
     def test_equals_argument_order(self):
         """
         Test equals predicate functions correctly regardless of the order
-        of the inputs. See issue #317. 
+        of the inputs. See issue #317.
         """
         coords = ((0, 0), (1, 0), (1, 1), (0, 0))
         ls = LineString(coords)
         lr = LinearRing(coords)
-        
+
         self.assertFalse(ls.__eq__(lr))  # previously incorrectly returned True
         self.assertFalse(lr.__eq__(ls))
         self.assertFalse(ls == lr)
         self.assertFalse(lr == ls)
-        
+
         ls_clone = LineString(coords)
         lr_clone = LinearRing(coords)
 
@@ -108,6 +109,13 @@ class LineStringTestCase(unittest.TestCase):
         self.assertEqual('LineString',
                          lgeos.GEOSGeomType(copy._geom).decode('ascii'))
 
+    def test_from_single_coordinate(self):
+        """Test for issue #486"""
+        coords = [[-122.185933073564, 37.3629353839073]]
+        with pytest.raises(ValueError):
+            ls = LineString(coords)
+            ls.geom_type # caused segfault before fix
+
 
     @unittest.skipIf(not numpy, 'Numpy required')
     def test_numpy(self):
@@ -157,7 +165,7 @@ class LineStringTestCase(unittest.TestCase):
         # Test array interface of empty linestring
         le = LineString()
         a = asarray(le)
-        assert(a.shape[0], 0)
+        self.assertEqual(a.shape[0], 0)
 
 
 def test_suite():
