@@ -78,6 +78,10 @@ class LineStringTestCase(unittest.TestCase):
         p_null.coords = (1, 2)
         self.assertEqual(p_null.coords[:], [(1.0, 2.0)])
 
+        # Passing > 3 arguments to Point is erroneous
+        with self.assertRaises(TypeError):
+            Point(1.0, 2.0, 3.0, 4.0)
+
     @unittest.skipIf(not numpy, 'Numpy required')
     def test_numpy(self):
 
@@ -140,5 +144,11 @@ class LineStringTestCase(unittest.TestCase):
         self.assertEqual(a.shape[0], 0)
 
 
+def test_empty_point_bounds():
+    """The bounds of an empty point is an empty tuple"""
+    p = Point()
+    assert p.bounds == ()
+
+
 def test_suite():
     return unittest.TestLoader().loadTestsFromTestCase(LineStringTestCase)
